==> s-page-0.0.6.tgz: package/src/hooks/useColumns.tsx <==
import * as React from "react";
const { useState, useEffect } = React;
import SButton from "../comps/SButton";
import { isFn, isArr } from "../utils/tool";
export default function(filters: [], tableColumns: [], openModalFn: Function) {
  const [columns, setColumns] = useState([]);
  useEffect(() => {
    let res: any = [];
    filters.forEach(
      ({ label, key, inTable = true, tableRender, tableColumn }: any) => {
        if (inTable) {
          res.push({
            title: label,
            dataIndex: key,
            key,
            render: tableRender,
            ...tableColumn
          });
        }
      }
    );
    res = res.concat(
      tableColumns.map(({ buttons, dataIndex, ...rest }: any) => {
        if (isArr(buttons)) {
          rest.render = (_text: any, record: any) => {
            return buttons.map(
              ({
                hide,
                disable,
                openModal = true,
                modalRender,
                modalProps,
                ...buttonsRest
              }: any) => {
                if (isFn(hide) && hide(record)) return null;
                if (isFn(disable)) {
                  buttonsRest.props = {
                    ...buttonsRest.props,
                    disabled: disable(record)
                  };
                }
                if (openModal)
                  buttonsRest.handler = () => {
                    openModalFn(record, modalRender, modalProps);
                  };
                return (
                  <SButton
                    style={{ marginRight: 5 }}
                    key={buttonsRest.label}
                    {...buttonsRest}
                  />
                );
              }
            );
          };
          dataIndex = dataIndex || rest.title;
        }
        return {
          dataIndex,
          key: dataIndex,
          ...rest
        };
      })
    );
    setColumns(res);
  }, [filters, tableColumns]);
  return columns;
}

==> s-page-0.0.8.tgz: package/src/hooks/useColumns.tsx <==
import * as React from "react";
const { useState, useEffect } = React;
import SButton from "../comps/SButton";
import { isFn, isArr } from "../utils/tool";
export default function(filters: [], tableColumns: [], openModalFn: Function) {
  const getColumns = () => {
    let res: any = [];
    filters.forEach(
      ({
        label,
        key,
        inTable = true,
        tableRender,
        tableColumn,
        tableKey
      }: any) => {
        if (inTable) {
          res.push({
            title: label,
            dataIndex: tableKey || key,
            key,
            render: tableRender,
            ...tableColumn
          });
        }
      }
    );
    res = res.concat(
      tableColumns.map(({ buttons, dataIndex, ...rest }: any) => {
        if (isArr(buttons)) {
          rest.render = (_text: any, record: any) => {
            return buttons.map(
              ({
                hide,
                disable,
                openModal = true,
                modalRender,
                modalProps,
                ...buttonsRest
              }: any) => {
                if (isFn(hide) && hide(record)) return null;
                if (isFn(disable)) {
                  buttonsRest.props = {
                    ...buttonsRest.props,
                    disabled: disable(record)
                  };
                }
                if (openModal)
                  buttonsRest.handler = () => {
                    openModalFn(record, modalRender, modalProps);
                  };
                return (
                  <SButton
                    style={{ marginRight: 5 }}
                    key={buttonsRest.label}
                    {...buttonsRest}
                  />
                );
              }
            );
          };
          dataIndex = dataIndex || rest.title;
        }
        return {
          dataIndex,
          key: dataIndex,
          ...rest
        };
      })
    );
    return res;
  };
  const [columns, setColumns] = useState(getColumns());
  useEffect(() => {
    setColumns(getColumns());
  }, [filters, tableColumns]);
  return columns;
}
